@@ -19,20 +19,20 @@
 # Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA 02111-1307 USA
 
-id = "f38b2d06b8b64e8a616232c9d79439fdeca0d412"
-date = "2016-06-26 21:26:32 +0000"
+id = "2caa475aa99f81c133c0d5047f4ad6f41d3f8064"
+date = "2016-10-10 17:31:35 +0000"
 branch = "None"
-tag = "lalsimulation-v1.6.0"
+tag = "lalsimulation-v1.6.1"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
 builder = "Adam Mercer <adam.mercer@ligo.org>"
-committer = "Adam Mercer <ramercer@gmail.com>"
+committer = "Adam Mercer <adam.mercer@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalsimulation-v1.6.0
-Id: f38b2d06b8b64e8a616232c9d79439fdeca0d412
+Tag: lalsimulation-v1.6.1
+Id: 2caa475aa99f81c133c0d5047f4ad6f41d3f8064
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -53,9 +53,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "f38b2d06b8b64e8a616232c9d79439fdeca0d412":
+    if foreign_id == "2caa475aa99f81c133c0d5047f4ad6f41d3f8064":
         return
-    msg = "Program id (f38b2d06b8b64e8a616232c9d79439fdeca0d412) does not match given id (%s)." % foreign_id
+    msg = "Program id (2caa475aa99f81c133c0d5047f4ad6f41d3f8064) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
