@@ -252,7 +252,7 @@ static int IMRPhenomDGenerateFD(
   IMRPhenomDPhaseCoefficients *pPhi = ComputeIMRPhenomDPhaseCoefficients(eta, chi1, chi2, finspin, extraParams);
   if (!pPhi) XLAL_ERROR(XLAL_EFUNC);
   PNPhasingSeries *pn = NULL;
-  XLALSimInspiralTaylorF2AlignedPhasing(&pn, m1, m2, chi1_in, chi2_in, 1.0, 1.0, LAL_SIM_INSPIRAL_SPIN_ORDER_35PN, extraParams);
+  XLALSimInspiralTaylorF2AlignedPhasing(&pn, m1, m2, chi1, chi2, 1.0, 1.0, LAL_SIM_INSPIRAL_SPIN_ORDER_35PN, extraParams);
   if (!pn) XLAL_ERROR(XLAL_EFUNC);
 
   // Subtract 3PN spin-spin term below as this is in LAL's TaylorF2 implementation
@@ -322,19 +322,22 @@ static int IMRPhenomDGenerateFD(
   return status;
 }
 
+////////////////////////////////////////////////
+// END OF REVIEWED CODE ////////////////////////
+////////////////////////////////////////////////
+
 /**
  * Function to return the frequency (in Hz) of the peak of the frequency
  * domain amplitude for the IMRPhenomD model.
  *
  * The peak is a parameter in the PhenomD model given by Eq. 20 in 1508.07253
  * where it is called f_peak in the paper.
- *  All input parameters should be in SI units. Angles should be in radians.
  */
 double XLALIMRPhenomDGetPeakFreq(
-    const REAL8 m1_in,                 /**< mass of companion 1 [kg] */
-    const REAL8 m2_in,                 /**< mass of companion 2 [kg] */
+    const REAL8 m1_in,                 /**< mass of companion 1 [Msun] */
+    const REAL8 m2_in,                 /**< mass of companion 2 [Msun] */
     const REAL8 chi1_in,               /**< aligned-spin of companion 1 */
-    const REAL8 chi2_in               /**< aligned-spin of companion 2 */
+    const REAL8 chi2_in                /**< aligned-spin of companion 2 */
 ) {
     // Ensure that m1 > m2 and that chi1 is the spin on m1
     REAL8 chi1, chi2, m1, m2;
@@ -373,3 +376,184 @@ double XLALIMRPhenomDGetPeakFreq(
 
     return PeakFreq;
 }
+
+
+// protoype
+static double PhenDPhaseDerivFrequencyPoint(double Mf, IMRPhenomDPhaseCoefficients *p, PNPhasingSeries *pn);
+
+/**
+ * Helper function to return the value of the frequency derivative of the
+ * Fourier domain phase.
+ * This is function is wrapped by IMRPhenomDPhaseDerivative and used
+ * when estimating the length of the time domain version of the waveform.
+ * unreviewed
+ */
+static double PhenDPhaseDerivFrequencyPoint(double Mf, IMRPhenomDPhaseCoefficients *p, PNPhasingSeries *pn)
+{
+
+  // split the calculation to just 1 of 3 possible mutually exclusive ranges
+
+  if (!StepFunc_boolean(Mf, p->fInsJoin))	// Inspiral range
+  {
+      double DPhiIns = DPhiInsAnsatzInt(Mf, p, pn);
+	  return DPhiIns;
+  }
+
+  if (StepFunc_boolean(Mf, p->fMRDJoin))	// MRD range
+  {
+      double DPhiMRDval = DPhiMRD(Mf, p) + p->C2MRD;
+	  return DPhiMRDval;
+  }
+
+  //	Intermediate range
+  double DPhiInt = DPhiIntAnsatz(Mf, p) + p->C2Int;
+  return DPhiInt;
+}
+
+/**
+* Estimates the length of the time domain IMRPhenomD signal
+* This does NOT taking into account any tapering that is used to condition the
+* Fourier domain waveform to compute the inverse Fourer transform.
+* To estimate the length we assume that the waveform only reaches the
+* the highest physics frequency i.e. the ringdown frequency.
+* unreviewed
+*/
+double XLALSimIMRPhenomDChirpTime(
+    const REAL8 m1_SI,                 /**< Mass of companion 1 (kg) */
+    const REAL8 m2_SI,                 /**< Mass of companion 2 (kg) */
+    const REAL8 chi1_in,               /**< aligned-spin of companion 1 */
+    const REAL8 chi2_in,               /**< aligned-spin of companion 2 */
+    const REAL8 fHzSt                  /**< arbitrary starting frequency in Hz */
+) {
+
+    if (fHzSt <= 0) XLAL_ERROR(XLAL_EDOM, "fHzSt must be positive\n");
+
+    if (chi1_in > 1.0 || chi1_in < -1.0 || chi2_in > 1.0 || chi2_in < -1.0)
+      XLAL_ERROR(XLAL_EDOM, "Spins outside the range [-1,1] are not supported\n");
+
+    /* external: SI; internal: solar masses */
+    const REAL8 m1_in = m1_SI / LAL_MSUN_SI;
+    const REAL8 m2_in = m2_SI / LAL_MSUN_SI;
+
+    REAL8 chi1, chi2, m1, m2;
+    if (m1_in>m2_in) {
+       chi1 = chi1_in;
+       chi2 = chi2_in;
+       m1   = m1_in;
+       m2   = m2_in;
+    } else { // swap spins and masses
+       chi1 = chi2_in;
+       chi2 = chi1_in;
+       m1   = m2_in;
+       m2   = m1_in;
+    }
+
+    // check that starting frequency is not higher than the peak frequency
+    const REAL8 fHzPeak = XLALIMRPhenomDGetPeakFreq(m1, m2, chi1, chi2);
+    if (fHzSt > fHzPeak){
+        XLAL_PRINT_WARNING("Starting frequency = %f Hz is higher IMRPhenomD peak frequency %f Hz. Results may be unreliable.", fHzSt, fHzPeak);
+    }
+
+    int status = init_useful_powers(&powers_of_pi, LAL_PI);
+    XLAL_CHECK(XLAL_SUCCESS == status, status, "Failed to initiate useful powers of pi.");
+
+    const REAL8 M = m1 + m2;
+    const REAL8 eta = m1 * m2 / (M * M);
+
+    if (eta > 0.25 || eta < 0.0)
+      XLAL_ERROR(XLAL_EDOM, "Unphysical eta. Must be between 0. and 0.25\n");
+
+    // compute geometric frequency
+    const REAL8 M_sec = M * LAL_MTSUN_SI;
+    const REAL8 MfSt = M_sec * fHzSt;
+
+    // Calculate phenomenological parameters
+    const REAL8 finspin = FinalSpin0815(eta, chi1, chi2); //FinalSpin0815 - 0815 is like a version number
+
+    if (finspin < MIN_FINAL_SPIN)
+            XLAL_PRINT_WARNING("Final spin (Mf=%g) and ISCO frequency of this system are small, \
+                            the model might misbehave here.", finspin);
+    const LALSimInspiralTestGRParam *extraParams = NULL;
+    IMRPhenomDPhaseCoefficients *pPhi = ComputeIMRPhenomDPhaseCoefficients(eta, chi1, chi2, finspin, extraParams);
+    if (!pPhi) XLAL_ERROR(XLAL_EFUNC);
+    PNPhasingSeries *pn = NULL;
+    XLALSimInspiralTaylorF2AlignedPhasing(&pn, m1, m2, chi1, chi2, 1.0, 1.0, LAL_SIM_INSPIRAL_SPIN_ORDER_35PN, extraParams);
+    if (!pn) XLAL_ERROR(XLAL_EFUNC);
+
+    // Subtract 3PN spin-spin term below as this is in LAL's TaylorF2 implementation
+    // (LALSimInspiralPNCoefficients.c -> XLALSimInspiralPNPhasing_F2), but
+    // was not available when PhenomD was tuned.
+    pn->v[6] -= (Subtract3PNSS(m1, m2, M, chi1, chi2) * pn->v[0]);
+
+
+    PhiInsPrefactors phi_prefactors;
+    status = init_phi_ins_prefactors(&phi_prefactors, pPhi, pn);
+    XLAL_CHECK(XLAL_SUCCESS == status, status, "init_phi_ins_prefactors failed");
+
+    // Compute coefficients to make phase C^1 continuous (phase and first derivative)
+    ComputeIMRPhenDPhaseConnectionCoefficients(pPhi, pn, &phi_prefactors);
+
+    // We estimate the length of the time domain signal (i.e., the chirp time)
+    // By computing the difference between the values of the Fourier domain
+    // phase derivative at two frequencies.
+    // Here the starting frequency is an input i.e., fHzSt, converted to Geometric units MfSt
+    // and the ending frequency is fixed to be the frequency of the amplitude peak in Geometric units MfPeak
+    // XLALIMRPhenomDGetPeakFreq output is in Hz, covert to Mf via / M_sec
+    const REAL8 MfPeak = XLALIMRPhenomDGetPeakFreq(m1, m2, chi1, chi2) / M_sec;
+
+    // Compute phase derivative at starting frequency
+    const REAL8 dphifSt = PhenDPhaseDerivFrequencyPoint(MfSt, pPhi, pn);
+    // Compute phase derivative at ending (ringdown) frequency
+    const REAL8 dphifRD = PhenDPhaseDerivFrequencyPoint(MfPeak, pPhi, pn);
+    const REAL8 dphidiff = dphifRD - dphifSt;
+
+    // The length of time is estimated as dphidiff / 2 / pi * M (In units of seconds)
+    const REAL8 ChirpTimeSec = dphidiff / 2. / LAL_PI * M_sec;
+
+    LALFree(pPhi);
+    LALFree(pn);
+
+    return ChirpTimeSec;
+
+}
+
+/**
+* Function to return the final spin (spin of the remnant black hole)
+* as predicted by the IMRPhenomD model. The final spin is calculated using
+* the phenomenological fit described in PhysRevD.93.044006 Eq. 3.6.
+* unreviewed
+*/
+double XLALSimIMRPhenomDFinalSpin(
+    const REAL8 m1_in,                 /**< mass of companion 1 [Msun] */
+    const REAL8 m2_in,                 /**< mass of companion 2 [Msun] */
+    const REAL8 chi1_in,               /**< aligned-spin of companion 1 */
+    const REAL8 chi2_in               /**< aligned-spin of companion 2 */
+) {
+    // Ensure that m1 > m2 and that chi1 is the spin on m1
+    REAL8 chi1, chi2, m1, m2;
+    if (m1_in>m2_in) {
+       chi1 = chi1_in;
+       chi2 = chi2_in;
+       m1   = m1_in;
+       m2   = m2_in;
+    } else { // swap spins and masses
+       chi1 = chi2_in;
+       chi2 = chi1_in;
+       m1   = m2_in;
+       m2   = m1_in;
+    }
+
+    const REAL8 M = m1 + m2;
+
+    REAL8 eta = m1 * m2 / (M * M);
+    if (eta > 0.25 || eta < 0.0)
+      XLAL_ERROR(XLAL_EDOM, "Unphysical eta. Must be between 0. and 0.25\n");
+
+    REAL8 finspin = FinalSpin0815(eta, chi1, chi2);
+
+    if (finspin < MIN_FINAL_SPIN)
+          XLAL_PRINT_WARNING("Final spin (Mf=%g) and ISCO frequency of this system are small, \
+                          the model might misbehave here.", finspin);
+
+    return finspin;
+}
