@@ -216,7 +216,7 @@ extern "C" {
 /**
  * Enum that specifies the PN approximant to be used in computing the waveform.
  */
-typedef enum {
+typedef enum tagApproximant {
    TaylorT1, 		/**< Time domain Taylor approximant in which the energy and flux are both kept
                          * as Taylor expansions and a first order ordinary differential equation is solved
                          * or the GW phase as a function of \f$t\f$; Outputs a time-domain wave.
@@ -312,7 +312,11 @@ typedef enum {
    SEOBNRv2_opt,	/**< Optimized Spin-aligned EOBNR model v2
                          * @remarks Implemented in lalsimulation (time domain). */
    SEOBNRv3,		/**< Spin precessing EOBNR model v3
-                         * @todo Fix implementation in lalsimulation (time domain). */
+                         * @remarks Implemented in lalsimulation (time domain). */
+   SEOBNRv4,		/**< Spin nonprecessing EOBNR model v4 
+                         * @remarks Implemented in lalsimulation (time domain). */
+   SEOBNRv4_opt,	/**< Optimized Spin-aligned EOBNR model v4
+                         * @remarks Implemented in lalsimulation (time domain). */
    SEOBNRv1_ROM_EffectiveSpin, /**< Single-spin frequency domain reduced order model of spin-aligned EOBNR model SEOBNRv1 See [Purrer:2014fza]
                                 * @remarks Implemented in lalsimulation (frequency domain). */
    SEOBNRv1_ROM_DoubleSpin, /**< Double-spin frequency domain reduced order model of spin-aligned EOBNR model SEOBNRv1 See [Purrer:2014fza]
@@ -323,6 +327,10 @@ typedef enum {
                              * @remarks Implemented in lalsimulation (frequency domain). */
    SEOBNRv2_ROM_DoubleSpin_HI, /**< High resolution low-mass double-spin frequency domain reduced order model of spin-aligned EOBNR model SEOBNRv2
                                 * @remarks Implemented in lalsimulation (frequency domain). */
+   Lackey_Tidal_2013_SEOBNRv2_ROM, /**< Frequency domain tidal model based on reduced order model of SEOBNRv2
+                                * @remarks Implemented in lalsimulation (frequency domain). */
+   SEOBNRv4_ROM, /**< Low-mass double-spin frequency domain reduced order model of spin-aligned EOBNR model SEOBNRv4
+                                * @remarks Implemented in lalsimulation (frequency domain). */
    HGimri,		/**< Time domain inspiral-merger-ringdown waveform for quasi-circular intermediate mass-ratio inspirals [Huerta & Gair arXiv:1009.1985]
                          * @remarks Implemented in lalsimulation (time domain). */
    IMRPhenomA,		/**< Time domain (non-spinning) inspiral-merger-ringdown waveforms generated from the inverse FFT of IMRPhenomFA.
@@ -362,7 +370,7 @@ typedef enum {
  } Approximant;
 
 /** Enum of various frequency functions */
-typedef enum {
+typedef enum tagFrequencyFunction {
     fSchwarzISCO, /**< Schwarzschild ISCO */
     fIMRPhenomAFinal, /**< Final frequency of IMRPhenomA */
     fIMRPhenomBFinal, /**< Final of IMRPhenomB */
@@ -374,11 +382,13 @@ typedef enum {
     fSEOBNRv1RD, /**< Dominant ringdown frequency in SEOBNRv1 */
     fSEOBNRv2Peak, /**< Frequency of the peak amplitude in SEOBNRv2 */
     fSEOBNRv2RD, /**< Dominant ringdown frequency in SEOBNRv2 */
+    fSEOBNRv4Peak, /**< Frequency of the peak amplitude in SEOBNRv4 */
+    fSEOBNRv4RD, /**< Dominant ringdown frequency in SEOBNRv4 */
     NumFreqFunctions /**< Number of elements in the enum */
  } FrequencyFunction;
 
 /** Enum of possible values to use for post-Newtonian order. */
-typedef enum {
+typedef enum tagLALPNOrder {
   LAL_PNORDER_NEWTONIAN,	/**< Newtonain (leading) order */
   LAL_PNORDER_HALF,		/**< 0.5PN <==> O(v) */
   LAL_PNORDER_ONE,		/**< 1PN <==> O(v^2) */
@@ -392,7 +402,7 @@ typedef enum {
  } LALPNOrder;
 
 /** Enumeration to specify the tapering method to apply to the waveform */
-typedef enum
+typedef enum tagLALSimInspiralApplyTaper
 {
   LAL_SIM_INSPIRAL_TAPER_NONE,		/**< No tapering */
   LAL_SIM_INSPIRAL_TAPER_START,		/**< Taper the start of the waveform */
@@ -402,12 +412,12 @@ typedef enum
 }  LALSimInspiralApplyTaper;
 
 /** Enumeration to specify time or frequency domain */
-typedef enum {
+typedef enum tagLALSimulationDomain {
   LAL_SIM_DOMAIN_TIME,
   LAL_SIM_DOMAIN_FREQUENCY
  } LALSimulationDomain;
 
-typedef enum {
+typedef enum tagSpinSupport {
    LAL_SIM_INSPIRAL_SPINLESS, /** These approximants cannot include spin terms */
    LAL_SIM_INSPIRAL_SINGLESPIN, /** These approximants support a signle spin (by default that is the object 1)*/
    LAL_SIM_INSPIRAL_ALIGNEDSPIN, /** These approximants can include spins aligned with L_N */
@@ -415,7 +425,7 @@ typedef enum {
    LAL_SIM_INSPIRAL_NUMSPINSUPPORT	/**< Number of elements in enum, useful for checking bounds */
  } SpinSupport;
 
-typedef enum {
+typedef enum tagTestGRaccept {
   LAL_SIM_INSPIRAL_NO_TESTGR_PARAMS,   /** These approximants cannot accept testGR params as input params */
   LAL_SIM_INSPIRAL_TESTGR_PARAMS,      /** These approximants accept testGR params as input params */
   LAL_SIM_INSPIRAL_NUM_TESTGR_ACCEPT  /**< Number of elements in enum, useful for checking bounds */
@@ -769,6 +779,8 @@ int XLALSimInspiralTaylorF2RedSpinComputeNoiseMoments(REAL8Vector *momI_0, REAL8
 void XLALSimInspiralTaylorF2RedSpinChirpTimesFromMchirpEtaChi(double *theta0, double *theta3, double *theta3s, double mc, double eta, double chi, double fLow);
 void XLALSimInspiralTaylorF2RedSpinMchirpEtaChiFromChirpTimes(double *mc, double *eta, double *chi, double theta0, double theta3, double theta3s, double fLow);
 
+REAL8 XLALSimInspiralfLow2fStart(REAL8 fLow, INT4 ampOrder, INT4 approximant);
+
 /* waveform tapering routines */
 /* in module LALSimInspiralWaveformTaper.c */
 
