@@ -504,6 +504,8 @@ int main (int argc , char **argv) {
     }
 
     /* clean up */
+    XLALDestroyREAL8TimeSeries(hplus);
+    XLALDestroyREAL8TimeSeries(hcross);
     XLALSimInspiralDestroyWaveformFlags(params->waveFlags);
     XLALSimInspiralDestroyTestGRParam(params->nonGRparams);
     XLALFree(params);
